from sdgs import BaseSdgs, SdgsResponse

from . import AuthToken


class BaseAuth(BaseSdgs):
    def login(self, username: str, password: str) -> AuthToken:
        res = self.session.get("https://dashboard-sdgs.kemendesa.go.id/")
        # AuthToken
        assert res.ok
        url = self.url_api("auth/token")
        data = {"username": username, "password": password}
        res = self.session.post(url, data)
        assert res.ok
        res_data = SdgsResponse.from_str(res.text, AuthToken)
        self.session.headers.update(res_data.data.token.token_header)
        return res_data.data



import attr


@attr.dataclass
class Capaian:
    surveyDesa: int
    surveyRT: int
    surveyKeluarga: int
    surveyIndividu: int


@attr.dataclass
class CapaianNasional:
    perolehanNasional: Capaian
    hariIniNasional: Capaian



from typing import List

from . import BaseAuth
from .model import CapaianNasional
from .model import Wilayah

from .survey_individu import SurveyIndividu


class Sdgs(BaseAuth):
    def __init__(
        self,
        username: str,
        password: str,
        api_server="https://sdgsdev.kemendesa.go.id/",
    ):
        super().__init__(api_server=api_server)
        self.token = self.login(username, password)
        self._survey_individu = SurveyIndividu(self)

    @property
    def survey_individu(self) -> SurveyIndividu:
        return self._survey_individu

    def getCapaianNasional(self) -> CapaianNasional:
        return self.api_get_to_res("/dashboard/getCapaianNasional", CapaianNasional)

    def wilayah(self, jenis: str = None, wilayah_id: str = None) -> List[Wilayah]:
        if jenis is None or wilayah_id is None:
            return self.api_get_to_res("/wilayah/prov", List[Wilayah])
        if jenis not in ("desa", "kecamatan", "kota"):
            raise ValueError("jenis harus berupa desa kecamatan atau kota")
        if jenis == "desa" and len(wilayah_id) == 7:
            return self.api_get_to_res(f"/wilayah/desa/{wilayah_id}", List[Wilayah])
        if jenis == "kecamatan" and len(wilayah_id) >= 4:
            return self.api_get_to_res(
                f"/wilayah/kecamatan/{wilayah_id[0:4]}", List[Wilayah]
            )
        if jenis == "kota" and len(wilayah_id) >= 2:
            return self.api_get_to_res(
                f"/wilayah/kota/{wilayah_id[0:2]}", List[Wilayah]
            )
        raise ValueError("Wilayah tidak ditemukan")



# -*- coding: utf-8 -*-
from setuptools import setup

packages = \
['sdgs', 'sdgs.auth', 'sdgs.model', 'sdgs.survey_individu']

package_data = \
{'': ['*']}

install_requires = \
['attrs>=21.2.0,<22.0.0',
 'beautifulsoup4>=4.9.3,<5.0.0',
 'cattrs>=1.8.0,<2.0.0',
 'python-dateutil>=2.8.2,<3.0.0',
 'requests>=2.26.0,<3.0.0',
 'ujson>=4.0.2,<5.0.0']

setup_kwargs = {
    'name': 'sdgs-dashboard',
    'version': '0.1.0',
    'description': ' Modul python untuk dashboard sdgs kemendesa.',
    'long_description': '# sdgs-dashboard\n\n[![sdgs-dashboard - PyPi](https://img.shields.io/pypi/v/sdgs-dashboard)](https://pypi.org/project/sdgs-dashboard/)\n[![Supported Python versions](https://img.shields.io/pypi/pyversions/sdgs-dashboard)](https://pypi.org/project/sdgs-dashboard/)\n[![Donate Saweria](https://img.shields.io/badge/Donasi-Saweria-blue)](https://saweria.co/hexatester)\n[![LISENSI](https://img.shields.io/github/license/hexatester/sdgs-dashboard)](https://github.com/hexatester/sdgs-dashboard/blob/main/LICENSE)\n\nModul python untuk dashboard sdgs kemendesa.\n',
    'author': 'hexatester',
    'author_email': 'hexatester@protonmail.com',
    'maintainer': None,
    'maintainer_email': None,
    'url': 'https://github.com/hexatester/sdgs-dashboard',
    'packages': packages,
    'package_data': package_data,
    'install_requires': install_requires,
    'python_requires': '>=3.7.10,<4.0.0',
}


setup(**setup_kwargs)



from .version import __version__  # NOQA
from .response import SdgsResponse
from .base import BaseSdgs

from .auth import BaseAuth

from .sdgs import Sdgs

__all__ = ["BaseAuth", "BaseSdgs", "Sdgs", "SdgsResponse"]



import attr
from datetime import datetime


@attr.dataclass
class SurveyPagedData:
    id: int
    createdBy: str
    createdOn: str
    statusId: str
    uid: str
    namaProvinsi: str
    namaKota: str
    namaKecamatan: str
    namaDesa: str
    namaPembuat: str
    rt: str
    rw: str
    nokk: str
    nik: str
    nama: str

    def __str__(self):
        return f"{self.nama} [{self.nik}]"



from typing import List, TYPE_CHECKING

if TYPE_CHECKING:
    from sdgs_tools.sdgs import Sdgs

from . import SurveyPagedData


class SurveyIndividu:
    def __init__(self, sdgs: "Sdgs"):
        self.sdgs = sdgs

    def getSurveyPagedData(
        self,
        page: int = 1,
        search: str = "",
        pageSize: int = 50,
        isSortAsc: bool = True,
        kodeDesa: str = None,
    ) -> List[SurveyPagedData]:
        json_data = {
            "isSortAsc": isSortAsc,
            "kodeDesa": kodeDesa or self.sdgs.token.wilayah,
            "page": page,
            "pageSize": pageSize,
            "search": search,
        }
        return self.sdgs.api_post_to_res(
            "surveyIndividu/getSurveyPagedData",
            List[SurveyPagedData],
            json=json_data,
        )
